@@ -119,6 +119,8 @@ impl DxError {
     }
 }
 
+impl std::error::Error for DxError {}
+
 impl std::fmt::Display for DxError {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         self.write_as_str(f)
@@ -1959,6 +1961,10 @@ impl CommandList {
         }
     }
 
+    pub fn set_blend_factor(&self, blend_factor: [f32; 4]) {
+        unsafe { dx_call!(self.this, OMSetBlendFactor, blend_factor.as_ptr()) }
+    }
+
     pub fn set_compute_root_32bit_constant(
         &self,
         root_parameter_index: u32,
@@ -2520,7 +2526,9 @@ impl Handle {
 pub struct RootSignature {
     pub this: *mut ID3D12RootSignature,
 }
-impl_com_object_refcount_unnamed!(RootSignature);
+
+impl_com_object_set_get_name!(RootSignature);
+impl_com_object_refcount_named!(RootSignature);
 impl_com_object_clone_drop!(RootSignature);
 
 unsafe impl Send for RootSignature {}
@@ -2602,24 +2610,28 @@ pub struct PIXSupport {}
 
 impl PIXSupport {
     pub fn init() {
+        #[cfg(feature = "pix")]
         unsafe {
             raw_bindings::pix::pix_init_analysis();
         }
     }
 
     pub fn shutdown() {
+        #[cfg(feature = "pix")]
         unsafe {
             raw_bindings::pix::pix_shutdown_analysis();
         }
     }
 
     pub fn begin_capture() {
+        #[cfg(feature = "pix")]
         unsafe {
             raw_bindings::pix::pix_begin_capture();
         }
     }
 
     pub fn end_capture() {
+        #[cfg(feature = "pix")]
         unsafe {
             raw_bindings::pix::pix_end_capture();
         }
@@ -2630,6 +2642,7 @@ impl PIXSupport {
         marker: &str,
         color: u64,
     ) {
+        #[cfg(feature = "pix")]
         unsafe {
             // ToDo: allocation on every marker call is sad :(
             let marker = CString::new(marker)
@@ -2644,6 +2657,7 @@ impl PIXSupport {
     }
 
     pub fn end_event_cmd_list(cmd_list: &CommandList) {
+        #[cfg(feature = "pix")]
         unsafe {
             raw_bindings::pix::pix_end_event_cmd_list(
                 cmd_list.this
@@ -2657,6 +2671,7 @@ impl PIXSupport {
         marker: &str,
         color: u64,
     ) {
+        #[cfg(feature = "pix")]
         unsafe {
             let marker = CString::new(marker)
                 .expect("Cannot convert marker string to C string");
@@ -2669,6 +2684,7 @@ impl PIXSupport {
     }
 
     pub fn end_event_cmd_queue(cmd_queue: &CommandQueue) {
+        #[cfg(feature = "pix")]
         unsafe {
             raw_bindings::pix::pix_end_event_cmd_queue(
                 cmd_queue.this as *mut raw_bindings::pix::ID3D12CommandQueue,
